.. _pydl.goddard.math:

==========================================
Goddard math package (`pydl.goddard.math`)
==========================================

Introduction
------------

This is a placeholder for Goddard math package documentation.

.. automodapi:: pydl.goddard.math
   :no-inheritance-diagram:
